@@ -3,7 +3,8 @@
 #include "Zelemagp.h"
 
 	data 
-     *	RecoilKineMinE /250.e-6/,   ! < 250 keV ==> dE/dx
+     *	RecoilKineMinE /0.5d-3/,     !
+     *  KnockOnRatio  /0.1d0/,       ! 
      *  AnihiE /30.e-3/,            ! Eposi < 30 MeV, anihilation considered
      *  X0 /364.0/,                 ! radiation length of air in kg/m2
      *  Ecrit /81.e-3/,             ! critical energy of air in GeV
@@ -11,7 +12,7 @@
      *  MaxPhotoE /0./,             ! above this, PhotoElectric effect neg.
      *  MinPhotoProdE /150.e-3/,     ! below 150 MeV, no gp --> hadrons
      *	Es /19.3d-3/,                 ! scattering const. Note, not 21 MeV.
-     *  Knockon /.true./,            ! knockon is considered.
+     *  Knockon /.true./,            ! knockon is considered. Obsolete
      *  PhotoProd /.false./,        ! gp--> hadrons not considered.
      *  Moliere /1/                 ! Moliere scattering for non-electron 
 	end
