@@ -4,7 +4,7 @@ c       block data is surely enabled.
       external cblkdedx
       external cblkHeavy 
       external cblkManager 
-      external cblkStdAtmos
+c      external cblkStdAtmos
       external cblkXsec
       external cblkEvhnp
       external cblkIncident
