@@ -22,7 +22,7 @@ c
          ke = pj.fm.p(4) - pj.mass
 c
 
-         if(k .eq. kpion) then
+         if(k .eq. kpion .or. k .eq. keta) then
             if(pj.charge .ge. 0) then
                call cpiPluspXsec(ke, xs)
             else
