@@ -19,10 +19,10 @@ c         in MovedTrack. If it is too large, path is truncated. Also compute
 c         deflection.
 c
        if(TrackBefMove.p.charge .ne. 0) then
-          if(.not. (mod(HowGeomag, 10) .eq. 1 .and.
-     *                Zfirst .eq. 0.)) then
+c          if(.not. (mod(HowGeomag, 10) .eq. 1 .and.     this existed from uv4.92 to 5.13
+c     *                Zfirst .eq. 0.)) then
              call cputEnergyLoss
-          endif
+c          endif
           if(MoveStat .ne. Dead) then
              call cputDeflection
           endif
