@@ -45,7 +45,7 @@ c                HeightList has priority
        if(EndLevel .eq. 0) EndLevel = NoOfSites   ! 96.09.18
 c               set magnetic field for the deepest level. 
 c                 Magfield is 'ned' here
-       if(HowGeomag .gt. 20 ) then
+       if(HowGeomag .gt. 20 .and. HowGeomag .le. 30 ) then
           MagfieldNED.x = MagN
           MagfieldNED.y = MagE
           MagfieldNED.z = MagD
