@@ -167,7 +167,20 @@ c             sample interaction length
          endif
       endif
       call csetIntInf(collkgram, .false., 'coll')
+c          knockon
  100  continue
+      if( FromEpics) then
+c           knockon is treated in epics specially.
+      else
+         if(TrackBefMove.p.charge .ne. 0) then
+            call cKnockp(TrackBefMove.p, prob, path) ! path in r.l
+            if(prob .gt. 0.d0) then
+               call csetIntInf(path *X0, .false., 'knock')
+            else
+               call csetIntInf(Infty,   .false., 'knock')
+            endif
+         endif
+      endif
       end
 
 
