@@ -13,7 +13,7 @@ c     **************************************************
 
       integer moreptcl, jold, icon
       real*8 smallAS/1./   ! electrons < 1GeV cannot make AS at all.
-      real*8 u, iwgt	
+cc      real*8 u, iwgt	
 c     
       external cblkTracking
 c
@@ -29,16 +29,16 @@ c            AS generation.
 
 c         if(icon .eq. 0) then
 c            thin sampling
-            if(TrackBefMove.p.fm.p(4) .lt. Ethin) then
+c            if(TrackBefMove.p.fm.p(4) .lt. Ethin) then
 c                do thin sampling
-               iwgt = TrackBefMove.p.fm.p(4)/Ethin ! inverse weight
-               call rndc(u)
-               if(u .gt. iwgt) then
-                  icon =2       !  discard this ptcl
-               else
-                  TrackBefMove.wgt = TrackBefMove.wgt /iwgt
-               endif
-            endif    
+c               iwgt = TrackBefMove.p.fm.p(4)/Ethin ! inverse weight
+c               call rndc(u)
+c               if(u .gt. iwgt) then
+c                  icon =2       !  discard this ptcl
+c               else
+c                  TrackBefMove.wgt = TrackBefMove.wgt /iwgt
+c               endif
+c            endif    
 c         endif
 
          if(ObserveAS .and. icon .ne. 2) then
@@ -277,7 +277,7 @@ c         argon
          TargetProtonNo = 18
       endif
 
-      if(HowGeomag .le. 2) then
+      if(HowGeomag .le. 2 .or. HowGeomag .eq. 31) then
 c             distant; change of B is < 1 % 
          call clengSmallBC(TrackBefMove, distant)
 
@@ -389,7 +389,7 @@ c              convert kg/m2 into length
             leng = IntInfArray(i).length
             jcut = 0
          endif
-         if(leng .lt. minlen) then
+         if(leng .le. minlen) then
             if(jcut .ne. 0) then
                MoveStat = Truncated
             else
@@ -401,13 +401,11 @@ c              convert kg/m2 into length
             minlen = leng
          endif
       enddo
-
       if(IntInfArray(ProcessNo).decay .or. jcut .ne. 0) then
          IntInfArray(ProcessNo).thickness = clen2thick(h, 
      *      TrackBefMove.vec.coszenith, 
      *      IntInfArray(ProcessNo).length )
       endif
-
       end
 c     ***********************
 c          truncate a path of the particle, if the path
